AgentEvent

Enum AgentEvent 

pub enum AgentEvent {
    SessionInit {
        session_id: String,
        model: String,
    },
    Text(String),
    ToolUse {
        name: String,
        input: Value,
    },
    QuestionPending {
        request_id: String,
        questions: Value,
    },
    TurnComplete {
        result: Option<String>,
        subtype: String,
        num_turns: u32,
        duration_ms: u64,
        is_error: bool,
        session_id: String,
    },
    ToolApprovalPending {
        request_id: String,
        tool_name: String,
        tool_input: Value,
    },
    ToolProgress {
        tool_name: String,
    },
    ProcessExited {
        code: Option<i32>,
    },
}
Events emitted by an agent during a session.

Agents communicate asynchronously via events. Handlers receive these events through the AgentHandle.receiver channel and respond by:

  • Displaying text to the user
  • Posting tool activity notifications
  • Waiting for user input (questions)
  • Finalizing the turn when complete

Event Flow

  1. SessionInit - Session starts (provides session_id)
  2. Text, ToolUse, ToolProgress - Activity during the turn (may repeat)
  3. QuestionPending - If Claude asks a question (blocks until answered)
  4. TurnComplete - Turn finishes successfully

Alternatively, ProcessExited can occur at any time if the agent crashes.

Variants



SessionInit

Session initialized (carries session_id, model).

Fields

session_id: String
model: String


Text(String)

Text content from Claude.



ToolUse

Claude is using a tool.

Fields

name: String
input: Value


QuestionPending

Claude is asking the user a question via control_request (AskUserQuestion tool).

Fields

request_id: String
questions: Value


TurnComplete

A turn completed.

Fields

result: Option<String>
subtype: String
num_turns: u32
duration_ms: u64
is_error: bool
session_id: String


ToolApprovalPending

Claude wants to use a tool that requires user approval.

Fields

request_id: String
tool_name: String
tool_input: Value


ToolProgress

Tool progress heartbeat.

Fields

tool_name: String


ProcessExited

Agent process exited unexpectedly.

Fields

code: Option<i32>