pub struct TuningConfig {
pub slack_max_message_chars: usize,
pub session_ttl_days: i64,
pub live_update_interval_secs: u64,
pub rate_limit_interval_ms: u64,
pub max_accumulated_text_bytes: usize,
pub first_chunk_max_retries: u32,
pub log_preview_max_len: usize,
}Expand description
Performance and behavior tuning parameters. All fields have sensible defaults and are optional.
Fields
slack_max_message_chars: usizeSlack’s approximate max message length (characters) for chat.postMessage. Default: 39000
session_ttl_days: i64Session time-to-live in days. Sessions older than this are pruned. Default: 7
live_update_interval_secs: u64Live-mode message update interval in seconds. Default: 2
rate_limit_interval_ms: u64Minimum interval between Slack API write calls per channel (ms). Default: 1100
max_accumulated_text_bytes: usizeMaximum accumulated text size in bytes before flushing (prevents unbounded growth). Default: 1000000
first_chunk_max_retries: u32Max retries for posting the first chunk of a thread. Default: 3
log_preview_max_len: usizeMax length of message text shown in log previews. Default: 100